searchData={"items":[{"type":"module","title":"TTY0TTY","doc":"`tty0tty` creates 2 pseudo-ttys that are connected together allowing you to\nrun unit tests which use serial ports (like [`Circuits.UART`](https://github.com/elixir-circuits/circuits_uart))\nwithout the need for external hardware of adapters.\n\n```elixir\ndefmodule SerialTest do\n  use ExUnit.Case, async: true\n\n  test \"can open a serial port\" do\n    {:ok, uart} = Circuits.UART.start_link()\n\n    port_name = \"/tmp/dummy1\"\n\n    # Open serial port before use\n    :ok = TTY0TTY.open(port_name)\n\n    assert :ok = Cicuits.UART.open(uart, port_name)\n  end\nend\n```\n\nUnder the hood, `TTY0TTY.open/2` opens 2 devices (` `, and\n` -twin`) and connects their TX <-> RX to emulate the serial\nconnection. This allows you to also verifying reading serial data by sending\ndata to the connected twin port:\n\n```elixir\ndefmodule SerialTest do\n  use ExUnit.Case, async: true\n\n  test \"can read a serial port\" do\n    {:ok, uart} = Circuits.UART.start_link()\n\n    port_name = \"/tmp/dummy1\"\n\n    # Open serial port before use\n    :ok = TTY0TTY.open(port_name)\n\n    assert :ok = Cicuits.UART.open(uart, port_name)\n\n    File.write!([port_name, \"-twin\"], \"howdy!\")\n\n    assert_receive {:circuits_uart, ^port_name, \"howdy!\"}\n  end\nend\n```","ref":"TTY0TTY.html"},{"type":"function","title":"TTY0TTY.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TTY0TTY.html#child_spec/1"},{"type":"function","title":"TTY0TTY.close/1","doc":"Close an open tty0tty path","ref":"TTY0TTY.html#close/1"},{"type":"function","title":"TTY0TTY.list/0","doc":"List all the currently open tty0tty processes","ref":"TTY0TTY.html#list/0"},{"type":"function","title":"TTY0TTY.open/2","doc":"Open a null modem at the specified device path\n\nSupports MuonTrap options for customizing the modem startup.\nSee `MuonTrap.Options` for supported options.\n\nCreating the modem takes a variable amount of time across systems,\nso this blocks until the devices are confirmed open. This timing\ncan be controlled with a `:timeout` option in milliseconds (default 5000)\n\n> #### File Permissions {: .info}\n> Some systems heavily restrict the `/dev` path and attempting to open\n> a device there would fail without elevated privileges. Consider opening\n> devices in other places with user access, such as `/tmp` or `/mnt`","ref":"TTY0TTY.html#open/2"},{"type":"function","title":"TTY0TTY.start_link/1","doc":"","ref":"TTY0TTY.html#start_link/1"},{"type":"function","title":"TTY0TTY.whereis/1","doc":"Lookup where the tty0tty process is","ref":"TTY0TTY.html#whereis/1"},{"type":"extras","title":"TTY0TTY","doc":"# TTY0TTY\n\n[![Hex](https://img.shields.io/hexpm/v/tty0tty.svg \"Hex\")](https://hex.pm/packages/tty0tty)\n[![REUSE status](https://api.reuse.software/badge/github.com/jjcarstens/tty0tty)](https://api.reuse.software/info/github.com/jjcarstens/tty0tty)\n\nElixir port for [`tty0tty` null modem emulator](https://github.com/freemed/tty0tty)","ref":"readme.html"},{"type":"extras","title":"Use - TTY0TTY","doc":"This library is almost exclusively for testing purposes. `tty0tty` creates 2\npseudo-ttys that are connected together allowing you to run unit tests which\nuse serial ports (like [`Circuits.UART`](https://github.com/elixir-circuits/circuits_uart))\nwithout the need for external hardware of adapters.\n\n```elixir\ndefmodule SerialTest do\n  use ExUnit.Case, async: true\n\n  test \"can open a serial port\" do\n    {:ok, uart} = Circuits.UART.start_link()\n\n    port_name = \"/tmp/dummy1\"\n\n    # Open serial port before use\n    :ok = TTY0TTY.open(port_name)\n\n    assert :ok = Cicuits.UART.open(uart, port_name)\n  end\nend\n```\n\nUnder the hood, `TTY0TTY.open/2` opens 2 devices (` `, and\n` -twin`) and connects their TX <-> RX to emulate the serial\nconnection. This allows you to also verifying reading serial data by sending\ndata to the connected twin port:\n\n\n```elixir\ndefmodule SerialTest do\n  use ExUnit.Case, async: true\n\n  test \"can read a serial port\" do\n    {:ok, uart} = Circuits.UART.start_link()\n\n    port_name = \"/tmp/dummy1\"\n\n    # Open serial port before use\n    :ok = TTY0TTY.open(port_name)\n\n    assert :ok = Cicuits.UART.open(uart, port_name)\n\n    File.write!([port_name, \"-twin\"], \"howdy!\")\n\n    assert_receive {:circuits_uart, ^port_name, \"howdy!\"}\n  end\nend\n```","ref":"readme.html#use"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [v1.0.1] - 2025-01-14","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"* `TTY0TTY.open/2` now blocks until the pty devices are confirmed open to prevent\n  timing errors attempting to read/write before it has finished opening\n  (thanks @coop! :heart:)\n\n[v1.0.1]: https://github.com/jjcarstens/tty0tty/releases/tag/v1.0.1\n\n## [v1.0.0] - 2023-02-24\n\nInitial release to support opening, closing, and listing emulated ports.\n\n[v1.0.0]: https://github.com/jjcarstens/tty0tty/releases/tag/v1.0.0","ref":"changelog.html#added"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}